import{C as t,_ as e,p as i,D as s,c as r,h as n,m as a}from"./backend-ai-console-3b21519e.js";import{I as p}from"./input-behavior-4dc18641.js";class o extends p{}o.styles=[...p.styles,t("")],e([i({type:String}),s("design:type",String)],o.prototype,"pattern",void 0),e([i({type:Number}),s("design:type",Number)],o.prototype,"minLength",void 0),e([i({type:Number}),s("design:type",Number)],o.prototype,"maxLength",void 0);let l=class extends o{constructor(){super(...arguments),this.type="text"}renderFormElement(){return n` <input id="${this.formElementId}" .value="${this.value}" value="${a(this.initialValue)}" ?required="${this.required}" ?disabled="${this.disabled}" ?readonly="${this.readonly}" aria-label="${a(this.label)}" type="${a(this.type)}" name="${a(this.name)}" list="${a(this.list)}" pattern="${a(this.pattern)}" autocomplete="${a(this.autocomplete)}" minlength="${a(this.minLength)}" maxlength="${a(this.maxLength)}" min="${a(this.min)}" max="${a(this.max)}" tabindex="${this.disabled?-1:0}"> `}};l.styles=[...o.styles,t("")],e([i({type:String}),s("design:type",String)],l.prototype,"list",void 0),e([i({type:String,reflect:!0}),s("design:type",String)],l.prototype,"type",void 0),e([i({type:Number}),s("design:type",Number)],l.prototype,"min",void 0),e([i({type:Number}),s("design:type",Number)],l.prototype,"max",void 0),l=e([r("wl-textfield")],l);export{l as T,o as a};
